/*
Design by Free CSS Templates
Adapted for ACR CMS dragonfly theme
http://www.freecsstemplates.org
Released for free under a Creative Commons Attribution 2.5 License
*/

* {
	margin: 0;
	padding: 0;
}

body {
	text-align: justify;
	font-family: Georgia, "Times New Roman", Times, serif;
	font-size: 12px;
	color: #666666;
}

.container {
	background: #FFFFFF url(/acr/plugins/theme/statics/dragonfly/images/img01.gif) repeat-x;
}

h1, h2, h3 {
	color: #333333;
}

h1, h2 {
	margin-bottom: 20px;
	font-weight: normal;
}

h1 {
	font-size: 197%;
}

h2 {
	font-size: 152%;
}

h3 {
	font-size: 100%;
}

p, ul, ol {
	margin-bottom: 20px;
	line-height: 1.8em;
}

ul, ol {
	margin-left: 3em;
}

blockquote {
	padding-left: 3em;
	background: url(/acr/plugins/theme/statics/dragonfly/images/img08.gif) no-repeat;
	font-style: italic;
}

a:link {
	color: #1953A7;
}

a:active {
	color: #ED5C0C;
}

a:visited {
	color: #666666;
}

a:hover {
	text-decoration: none;
	color: #067600;
}

img {
	border: none;
}

img.left {
	float: left;
	margin: 0 20px 10px 0;
}

/* Header */

#header {
	width: 770px;
	height: 170px;
	margin: 0 auto;
}

#header h1 {
	float: left;
	width: 220px;
	height: 100px;
	margin: 0;
	padding: 70px 0 0 0;
	background: url(/acr/plugins/theme/statics/dragonfly/images/img02.jpg) no-repeat;
	text-align: center;
	font-size: 36px;
}

#header h2 {
	float: right;
	width: 530px;
	height: 86px;
	margin: 0;
	background: url(/acr/plugins/theme/statics/dragonfly/images/img03.jpg) no-repeat;
	padding: 84px 20px 0 0;
	text-align: right;
}

#header a {
	text-transform: lowercase;
	text-decoration: none;
	font-style: italic;
	font-weight: normal;
	color: #FFFFFF;
}

/* Menu */

#horizontal_menu {
	width: 770px;
	height: 65px;
	margin: 0 auto;
	border-right: 1px solid #EDEBD5;
}

.horizontal_menu ul {
	margin: 0;
	padding: 0;
	list-style: none;
}

.horizontal_menu li {
	display: inline;
}

.horizontal_menu a {
	display: block;
	float: left;
	width: 109px;
	height: 45px;
	padding: 20px 0 0 0;
	border-left: 1px solid #EDEBD5;
	text-transform: lowercase;
	text-decoration: none;
	text-align: center;
	font-size: 144%;
	color: #BABABA !important;
}

.horizontal_menu a:hover {
	background: #F7F7F4;
}

.horizontal_menu .acr_menu_selected a {
	background: #F49A24;
	color: #FFFFFF !important;
}

/* Page */

div#page {
	width: 770px;
	margin: 0 auto;
	padding: 20px 0;
}

/* Content */

#main {
	float: left;
	width: 550px;
	padding-top: 10px;
}

.acr_presentation {
	margin-bottom: 20px;
	padding: 0 20px;
	border-bottom: 1px solid #EDEBD5;
}

/* Sidebar */

#rightbar, #leftbar {
	float: right;
	width: 210px;
	padding: 5px;
	background: #EDEBD5;
}

#rightbar h2, #leftbar h2 {
	margin: 0;
	padding: 5px 15px;
	color: #FFFFFF;
}

#rightbar h3, #leftbar h3 {
	font-size: 85%;
	color: #FFFFFF;
}

#rightbar ul, #leftbar ul {
	margin: 0;
	padding: 15px;
	list-style: none;
}

#rightbar li, #leftbar li {
}

#rightbar a, #leftbar a {
	color: #FFFFFF;
}

.orangebox {
	background: url(/acr/plugins/theme/statics/dragonfly/images/img05.gif) repeat-y;
}

.orangebox h2 {
	background: url(/acr/plugins/theme/statics/dragonfly/images/img06.gif) repeat-y;
}

/* Footer */

#footer {
	clear: both;
	height: 100px;
	padding: 25px 0;
	background: #EDEBD5 url(/acr/plugins/theme/statics/dragonfly/images/img04.gif) repeat-x;
}

#footer p {
	margin: 0;
	text-align: center;
	font-size: 77%;
}

#footer a {
	color: #666666;
}
